local L = AceLibrary("AceLocale-2.2"):new("GridStatusControlPipes")

local AceOO = AceLibrary("AceOO-2.0")

local PipeFilter = AceOO.Class()


------------------------------------
--      General pipe filter       --
------------------------------------



function PipeFilter.prototype:init(pipe, id, db, options)
    PipeFilter.super.prototype.init(self, pipe, id, db, options)
    print("new filter")
    self.options = options
    self.db = db
    self.pipe = pipe
end

function PipeFilter.prototype:Filter(guid, color, text, value, maxValue, texture, start, duration, stack, ...)
    return guid, color, text, value, maxValue, texture, start, duration, stack, ...
end

function PipeFilter.prototype:Destroy()
end

function PipeFilter:GetName()
    return "not used"
end

function PipeFilter:RegisterFilterType(name, class)
    self.filterTypes = self.filterTypes or {}
    
    self.filterTypes[name] = class
    GridPipeClass:RegisterFilter(name, class)
end


------------------------------------
--          ToBarFilter           --
------------------------------------

local ToBarFilter = AceOO.Class(PipeFilter)
PipeFilter:RegisterFilterType("To-bar filter", ToBarFilter)

function ToBarFilter.prototype:init(pipe, id, db, options)
    ToBarFilter.super.prototype.init(self, pipe, id, db, options)
    pipe:StatusResending(true)
end

function ToBarFilter.prototype:Filter(guid, color, text, value, maxValue, texture, start, duration, stack, ...)
    if start and duration then
        value = start + duration - GetTime()
        maxValue = duration 
    end
    return guid, color, text, value, maxValue, texture, start, duration, stack, ...
end

function ToBarFilter:GetName()
    return "To-bar filter"
end

------------------------------------
--          ToTextFilter          --
------------------------------------

local ToTextFilter = AceOO.Class(PipeFilter)
PipeFilter:RegisterFilterType("To-text filter", ToTextFilter)

local function FormatText(val)
	local healthText
	if val > 999 then
		healthText = string.format("%.1fk", val/1000.0)
	else
		healthText = string.format("%d", val)
	end

	return healthText
end

function ToTextFilter.prototype:Filter(guid, color, text, value, maxValue, texture, start, duration, stack, ...)
    if value then
        
        text = FormatText(value)
    end
    return guid, color, text, value, maxValue, texture, start, duration, stack, ...
end

function ToTextFilter:GetName()
    return "To-text filter"
end


PipeFilterClass = PipeFilter
ToTextFilterClass = ToTextFilter
ToBarFilterClass = ToBarFilter